EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Feeds_DeleteFeed',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes the specified feed.'
GO

IF OBJECT_ID('[Feeds_DeleteFeed]') IS NOT NULL DROP PROCEDURE [Feeds_DeleteFeed]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Feeds_DeleteFeed]
(
	@Feed_Id INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY

	BEGIN TRANSACTION

		DECLARE @Feed_Name NVARCHAR(50)
		 SELECT @Feed_Name = [Feed_Name]
		   FROM [Feeds] WHERE [Feed_Id] = @Feed_Id
		IF @@ROWCOUNT = 0 BEGIN ROLLBACK RETURN END


		DELETE
		  FROM [FeedAdapters]
		 WHERE [Feed_Id] = @Feed_Id

		DELETE [Privileges]
		 WHERE [Feed_Id] = @Feed_Id

		DELETE [NuGetPackageSymbols]
		 WHERE [Feed_Id] = @Feed_Id

		DELETE [NuGetPackageSymbolsV2]
		 WHERE [Feed_Id] = @Feed_Id

		DELETE [NuGetPackages]
		 WHERE [Feed_Id] = @Feed_Id

        DELETE [PackagePromotions]
		 WHERE [From_Feed_Id] = @Feed_Id
            OR [To_Feed_Id] = @Feed_Id

	DELETE NPT
	  FROM [NpmPackageTags] NPT
	       INNER JOIN [NpmPackages] NP
		           ON NP.[Package_Id] = NPT.[Package_Id]
	 WHERE NP.[Feed_Id] = @Feed_Id

	DELETE NPV
	  FROM [NpmPackageVersions] NPV
	       INNER JOIN [NpmPackages] NP
		           ON NPV.[Package_Id] = NP.[Package_Id]
	 WHERE NP.[Feed_Id] = @Feed_Id

	DELETE [NpmPackages]
	 WHERE [Feed_Id] = @Feed_Id

	DELETE [BowerPackages]
	 WHERE [Feed_Id] = @Feed_Id

	DELETE MAF
	  FROM [MavenArtifactFiles] MAF
	       INNER JOIN [MavenArtifacts] MA
		           ON MA.[MavenArtifact_Id] = MAF.[MavenArtifact_Id]
	 WHERE MA.[Feed_Id] = @Feed_Id

	DELETE [MavenArtifacts]
	 WHERE [Feed_Id] = @Feed_Id

 	DELETE PGPV
	  FROM [ProGetPackageVersions] PGPV
	       INNER JOIN [ProGetPackages] PGP
		           ON PGPV.[ProGetPackage_Id] = PGP.[ProGetPackage_Id]
	 WHERE PGP.[Feed_Id] = @Feed_Id

	DELETE [ProGetPackages]
	 WHERE [Feed_Id] = @Feed_Id

	DELETE [EventOccurrences]
	 WHERE [Feed_Id] = @Feed_Id

	DELETE [Executions]
	 WHERE [Feed_Id] = @Feed_Id

	DELETE E
	  FROM [Executions] E
	 INNER JOIN [ScheduledTasks] ST
	         ON E.[ScheduledTask_Id] = ST.[ScheduledTask_Id]
	 WHERE ST.[Feed_Id] = @Feed_Id

	DELETE [ScheduledTasks]
	 WHERE [Feed_Id] = @Feed_Id

	DELETE [FeedRetentionRules]
	 WHERE [Feed_Id] = @Feed_Id

	DELETE [Feeds]
	 WHERE [Feed_Id] = @Feed_Id

	EXEC [Events_RaiseEvent] 'FEDDLF', NULL, 'Feed_Name', @Feed_Name

	COMMIT

END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Feeds_DeleteFeed] TO [ProGetUser_Role]
GO
